# -*- coding: utf-8 -*-

from derpconf.config import Config
import os
from api_pagador import settings

config_path = os.path.join(os.path.dirname(__file__), "config.conf")
if hasattr(settings, "PAGADOR_CONF_PATH") and settings.PAGADOR_CONF_PATH is not None:
    config_path = settings.PAGADOR_CONF_PATH

config = Config.load(config_path)

MEDIA_URL = config.MEDIA_URL

DEBUG = config.DEBUG

LIBS_MEIOS_DE_PAGAMENTO = config.LIBS_MEIOS_DE_PAGAMENTO

QUEUE_URL = config.QUEUE_URL
GRAVA_EVIDENCIA = config.GRAVA_EVIDENCIA
EVIDENCIA_URL = config.EVIDENCIA_URL

MODULO_PARAMETROS_INSTALACAO = config.MODULO_PARAMETROS_INSTALACAO

MERCADOPAGO_REDIRECT_URL = config.MERCADOPAGO_REDIRECT_URL
MERCADOPAGO_PREFERENCE_NOTIFICATION_URL = config.MERCADOPAGO_PREFERENCE_NOTIFICATION_URL